@@ -15,7 +15,9 @@
 from enum import Enum, Flag, auto
 from typing import Any, List, Optional, Tuple, TypeVar
 
-from ..exception import TBRNError
+import click
+
+from tensorbay.exception import TBRNError
 
 
 class _TBRNFlag(Flag):
@@ -118,23 +120,23 @@ class TBRN:
 
     Use as a generator:
 
-        >>> info = TBRN("VOC2010", "train", remote_path="2012_004330.jpg")
-        >>> info.type
+        >>> tbrn_info = TBRN("VOC2010", "train", remote_path="2012_004330.jpg")
+        >>> tbrn_info.type
         <TBRNType.NORMAL_FILE: 5>
-        >>> info.get_tbrn()
+        >>> tbrn_info.get_tbrn()
         'tb:VOC2010:train://2012_004330.jpg'
-        >>> print(info)
+        >>> print(tbrn_info)
         'tb:VOC2010:train://2012_004330.jpg'
 
     Use as a parser:
 
         >>> tbrn = "tb:VOC2010:train://2012_004330.jpg"
-        >>> info = TBRN(tbrn=tbrn)
-        >>> info.dataset
+        >>> tbrn_info = TBRN(tbrn=tbrn)
+        >>> tbrn_info.dataset
         'VOC2010'
-        >>> info.segment_name
+        >>> tbrn_info.segment_name
         'train'
-        >>> info.remote_path
+        >>> tbrn_info.remote_path
         '2012_004330.jpg'
 
     Arguments:
@@ -192,7 +194,7 @@ class TBRN:
         Optional[str],
     ]
 
-    def __init__(  # pylint: disable=too-many-locals
+    def __init__(
         self,
         dataset_name: Optional[str] = None,
         segment_name: Optional[str] = None,
@@ -265,8 +267,7 @@ class TBRN:
         return self.get_tbrn()
 
     def _check_type(self) -> Tuple[TBRNType, int]:
-        # https://github.com/PyCQA/pylint/issues/2224
-        flag = _TBRNFlag.FIELD_HEAD.value  # pylint: disable=no-member
+        flag = _TBRNFlag.FIELD_HEAD.value
         for i, name in enumerate(self._names, 1):
             if name is not None:
                 flag |= 1 << i
@@ -378,3 +379,15 @@ class TBRN:
         if self._names[4] is not None:
             tbrn = f"{tbrn}{TBRN._PATH_SEPARATOR}{self.remote_path}"
         return tbrn
+
+    def get_colored_tbrn(self, color: Optional[str] = "yellow") -> str:
+        """Get the colored tbrn string.
+
+        Arguments:
+            color: The color of the tbrn.
+
+        Returns:
+            The colored tbrn string.
+
+        """
+        return click.style(self.get_tbrn(), fg=color)
