@@ -23,24 +23,37 @@ Please refer to :class:`~tensorbay.dataset.dataset.FusionDataset` for more infor
 """
 
 import logging
+import os
+import shutil
+import tempfile
 from typing import TYPE_CHECKING, Any, Dict, Generator, Iterable, Iterator, Optional, Tuple, Union
 
 from ulid import ULID, from_timestamp
 
-from ..dataset import AuthData, Data, Frame, FusionSegment, Notes, RemoteData, Segment
-from ..exception import FrameError, InvalidParamsError, NameConflictError, ResourceNotExistError
-from ..label import Catalog
-from .diff import DataDiff, DatasetDiff, SegmentDiff
-from .lazy import PagingList
-from .log import UPLOAD_SEGMENT_RESUME_TEMPLATE
-from .requests import Tqdm, multithread_upload
-from .segment import _STRATEGIES, FusionSegmentClient, SegmentClient
-from .statistics import Statistics
-from .status import Status
-from .version import VersionControlClient
+from tensorbay.client.diff import DataDiff, DatasetDiff, SegmentDiff
+from tensorbay.client.lazy import PagingList
+from tensorbay.client.log import (
+    CACHE_SPACE_WARNING,
+    UPLOAD_SEGMENT_RESUME_TEMPLATE_CLI,
+    UPLOAD_SEGMENT_RESUME_TEMPLATE_SDK,
+)
+from tensorbay.client.requests import Tqdm, multithread_upload
+from tensorbay.client.segment import _STRATEGIES, FusionSegmentClient, SegmentClient
+from tensorbay.client.statistics import Statistics
+from tensorbay.client.status import Status
+from tensorbay.client.version import VersionControlClient
+from tensorbay.dataset import AuthData, Data, Frame, FusionSegment, Notes, RemoteData, Segment
+from tensorbay.exception import (
+    FrameError,
+    InvalidParamsError,
+    NameConflictError,
+    ResourceNotExistError,
+    StatusError,
+)
+from tensorbay.label import Catalog
 
 if TYPE_CHECKING:
-    from .gas import GAS
+    from tensorbay.client.gas import GAS
 
 logger = logging.getLogger(__name__)
 
@@ -82,6 +95,7 @@ class DatasetClientBase(VersionControlClient):
         self._name = name
         self._alias = alias
         self._is_public = is_public
+        self._cache_path = ""
 
     def _create_segment(self, name: str) -> None:
         post_data: Dict[str, Any] = {"name": name}
@@ -187,6 +201,50 @@ class DatasetClientBase(VersionControlClient):
         """
         return self._is_public
 
+    @property
+    def cache_enabled(self) -> bool:
+        """Whether the cache is enabled.
+
+        Returns:
+            Whether the cache is enabled.
+        """
+        return bool(self._cache_path) and not self.status.is_draft
+
+    def enable_cache(self, cache_path: str = "") -> None:
+        """Enable cache when open the remote data of the dataset.
+
+        Arguments:
+            cache_path: The path to store the cache.
+
+        Raises:
+            StatusError: When enable cache under draft status.
+
+        """
+        try:
+            self.status.check_authority_for_commit()
+        except StatusError as error:
+            raise StatusError("Cache is not available for datasets under draft status") from error
+
+        if cache_path:
+            self._cache_path = os.path.join(
+                os.path.abspath(os.path.expanduser(cache_path)), self.dataset_id
+            )
+        else:
+            self._cache_path = os.path.join(tempfile.gettempdir(), "tensorbay", self.dataset_id)
+        total_size = self.get_total_size()
+        print(
+            "To cache the entire dataset, "
+            f"please make sure there is free storage space larger than {total_size} bytes.\n"
+            "Note that cache will not work for datasets under draft status.\n\n"
+            f'The cache will be stored under "{self._cache_path}".\n'
+            "You can remove all the files after using."
+        )
+
+        os.makedirs(self._cache_path, exist_ok=True)
+        _, _, free = shutil.disk_usage(self._cache_path)
+        if free < total_size:
+            logger.warning(CACHE_SPACE_WARNING, free, total_size)
+
     def update_notes(
         self,
         *,
@@ -293,6 +351,20 @@ class DatasetClientBase(VersionControlClient):
             ).json()["labelStatistics"]
         )
 
+    def get_total_size(self) -> int:
+        """Get total data size of the dataset and the unit is byte.
+
+        Returns:
+            The total data size of the dataset.
+
+        """
+        self._status.check_authority_for_commit()
+
+        params: Dict[str, Any] = {"commit": self._status.commit_id}
+        return self._client.open_api_do(  # type: ignore[no-any-return]
+            "GET", "total-size", self._dataset_id, params=params
+        ).json()["totalSize"]
+
 
 class DatasetClient(DatasetClientBase):
     """This class defines :class:`DatasetClient`.
@@ -373,14 +445,14 @@ class DatasetClient(DatasetClientBase):
             lambda data: pbar.update_for_skip(not isinstance(data, RemoteData)),
             segment,  # type: ignore[arg-type]
         )
-        if skip_uploaded_files:
+        if not skip_uploaded_files:
+            segment_filter = all_data
+        else:
             done_set = set(segment_client.list_data_paths())
             segment_filter = filter(
                 lambda data: pbar.update_for_skip(data.target_remote_path not in done_set),
                 all_data,
             )
-        else:
-            segment_filter = all_data
 
         multithread_upload(
             # pylint: disable=protected-access
@@ -512,6 +584,7 @@ class DatasetClient(DatasetClientBase):
         jobs: int = 1,
         skip_uploaded_files: bool = False,
         quiet: bool = False,
+        _is_cli: bool = False,
     ) -> SegmentClient:
         """Upload a :class:`~tensorbay.dataset.segment.Segment` to the dataset.
 
@@ -527,6 +600,7 @@ class DatasetClient(DatasetClientBase):
             jobs: The number of the max workers in multi-thread uploading method.
             skip_uploaded_files: True for skipping the uploaded files.
             quiet: Set to True to stop showing the upload process bar.
+            _is_cli: Whether the method is called by CLI.
 
         Raises:
             Exception: When the upload got interrupted by Exception.
@@ -546,11 +620,17 @@ class DatasetClient(DatasetClientBase):
                     pbar=pbar,
                 )
         except Exception:
-            logger.error(
-                UPLOAD_SEGMENT_RESUME_TEMPLATE,
-                self._status.draft_number,
-                self._status.draft_number,
-            )
+            if _is_cli:
+                logger.error(
+                    UPLOAD_SEGMENT_RESUME_TEMPLATE_CLI,
+                    self._status.draft_number,
+                )
+            else:
+                logger.error(
+                    UPLOAD_SEGMENT_RESUME_TEMPLATE_SDK,
+                    self._status.draft_number,
+                    self._status.draft_number,
+                )
             raise
 
     def get_diff(self, *, head: Optional[Union[str, int]] = None) -> DatasetDiff:
@@ -816,7 +896,7 @@ class FusionDatasetClient(DatasetClientBase):
         segment: FusionSegment,
         *,
         jobs: int = 1,
-        skip_uploaded_files: bool = False,  # pylint: disable=unused-argument
+        skip_uploaded_files: bool = False,
         quiet: bool = False,
     ) -> FusionSegmentClient:
         """Upload a fusion segment object to the draft.
@@ -850,7 +930,7 @@ class FusionDatasetClient(DatasetClientBase):
                 )
         except Exception:
             logger.error(
-                UPLOAD_SEGMENT_RESUME_TEMPLATE,
+                UPLOAD_SEGMENT_RESUME_TEMPLATE_SDK,
                 self._status.draft_number,
                 self._status.draft_number,
             )
