@@ -18,7 +18,7 @@ from typing import Any, Dict, Generator, Optional, Type, Union, overload
 
 from typing_extensions import Literal
 
-from tensorbay.client.cloud_storage import CloudClient
+from tensorbay.client.cloud_storage import CloudClient, StorageConfig
 from tensorbay.client.dataset import DatasetClient, FusionDatasetClient
 from tensorbay.client.lazy import PagingList
 from tensorbay.client.log import UPLOAD_DATASET_RESUME_TEMPLATE
@@ -53,14 +53,15 @@ class GAS:
 
     def _generate_auth_storage_configs(
         self, name: Optional[str] = None, offset: int = 0, limit: int = 128
-    ) -> Generator[Dict[str, Any], None, int]:
+    ) -> Generator[StorageConfig, None, int]:
         params: Dict[str, Any] = {"offset": offset, "limit": limit}
         if name:
             params["name"] = name
 
-        response = self._client.open_api_do("GET", "auth-storage-configs", "", params=params).json()
+        response = self._client.open_api_do("GET", "storage-configs", "", params=params).json()
 
-        yield from response["configs"]
+        for config in response["configs"]:
+            yield StorageConfig.loads(config)
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
@@ -151,7 +152,7 @@ class GAS:
         response = self._client.open_api_do("GET", "users").json()
         return UserInfo.loads(response)
 
-    def get_auth_storage_config(self, name: str) -> Dict[str, Any]:
+    def get_auth_storage_config(self, name: str) -> StorageConfig:
         """Get the auth storage config with the given name.
 
         Arguments:
@@ -177,7 +178,7 @@ class GAS:
 
         return config
 
-    def list_auth_storage_configs(self) -> PagingList[Dict[str, Any]]:
+    def list_auth_storage_configs(self) -> PagingList[StorageConfig]:
         """List auth storage configs.
 
         Returns:
@@ -306,6 +307,23 @@ class GAS:
         self._client.open_api_do("POST", "storage-configs/azure", json=post_data)
         return CloudClient(name, self._client)
 
+    def create_local_storage_config(self, name: str, file_path: str, endpoint: str) -> None:
+        """Create a local auth storage config.
+
+        Arguments:
+            name: The required local storage config name.
+            file_path: The dataset storage path under the local storage.
+            endpoint: The external IP address of the local storage.
+
+        """
+        post_data = {
+            "name": name,
+            "filePath": file_path,
+            "endpoint": endpoint,
+        }
+
+        self._client.open_api_do("POST", "storage-configs/local", json=post_data)
+
     def get_cloud_client(self, name: str) -> CloudClient:
         """Get a cloud client used for interacting with cloud platform.
 
