@@ -27,20 +27,19 @@ import os
 import time
 from copy import deepcopy
 from itertools import zip_longest
-from typing import TYPE_CHECKING, Any, Callable, Dict, Generator, Iterable, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any, Dict, Generator, Iterable, Optional, Tuple, Union
 
 import filetype
 from requests_toolbelt import MultipartEncoder
 from ulid import ULID, from_timestamp
 
 from tensorbay.client.lazy import LazyPage, PagingList
-from tensorbay.client.requests import config
 from tensorbay.client.status import Status
 from tensorbay.dataset import AuthData, Data, Frame, RemoteData
-from tensorbay.exception import FrameError, InvalidParamsError, ResponseError
+from tensorbay.exception import FrameError, InvalidParamsError, ResourceNotExistError, ResponseError
 from tensorbay.label import Label
 from tensorbay.sensor.sensor import Sensor, Sensors
-from tensorbay.utility import FileMixin, chunked, locked
+from tensorbay.utility import URL, FileMixin, chunked, config, locked
 
 if TYPE_CHECKING:
     from tensorbay.client.dataset import DatasetClient, FusionDatasetClient
@@ -49,18 +48,6 @@ _STRATEGIES = {"abort", "override", "skip"}
 _MASK_KEYS = ("semantic_mask", "instance_mask", "panoptic_mask")
 
 
-class _UrlGetters:
-    def __init__(self, urls: LazyPage[str]) -> None:
-        self._urls = urls
-
-    def __getitem__(self, index: int) -> Callable[[str], str]:
-        return lambda _: self._urls.items[index].get()
-
-    def update(self) -> None:
-        """Update all urls."""
-        self._urls.pull()
-
-
 class SegmentClientBase:
     """This class defines the basic concept of :class:`SegmentClient`.
 
@@ -135,6 +122,24 @@ class SegmentClientBase:
         response = self._client.open_api_do("GET", "data/urls", self._dataset_id, params=params)
         return response.json()  # type: ignore[no-any-return]
 
+    def _get_data_details(self, remote_path: str) -> Dict[str, Any]:
+        params: Dict[str, Any] = {
+            "segmentName": self._name,
+            "remotePath": remote_path,
+        }
+        params.update(self._status.get_status_info())
+
+        if config.is_internal:
+            params["isInternal"] = True
+
+        response = self._client.open_api_do("GET", "data/details", self._dataset_id, params=params)
+        try:
+            data_details = response.json()["dataDetails"][0]
+        except IndexError as error:
+            raise ResourceNotExistError(resource="data", identification=remote_path) from error
+
+        return data_details  # type: ignore[no-any-return]
+
     def _list_data_details(self, offset: int = 0, limit: int = 128) -> Dict[str, Any]:
         params: Dict[str, Any] = {
             "segmentName": self._name,
@@ -149,6 +154,27 @@ class SegmentClientBase:
         response = self._client.open_api_do("GET", "data/details", self._dataset_id, params=params)
         return response.json()  # type: ignore[no-any-return]
 
+    def _get_mask_url(self, mask_type: str, remote_path: str) -> str:
+        params: Dict[str, Any] = {
+            "segmentName": self._name,
+            "maskType": mask_type,
+            "remotePath": remote_path,
+        }
+        params.update(self._status.get_status_info())
+
+        if config.is_internal:
+            params["isInternal"] = True
+
+        response = self._client.open_api_do("GET", "masks/urls", self._dataset_id, params=params)
+        try:
+            mask_url = response.json()["urls"][0]["url"]
+        except IndexError as error:
+            raise ResourceNotExistError(
+                resource="{mask_type} of data", identification=remote_path
+            ) from error
+
+        return mask_url  # type: ignore[no-any-return]
+
     def _list_mask_urls(self, mask_type: str, offset: int = 0, limit: int = 128) -> Dict[str, Any]:
         params: Dict[str, Any] = {
             "segmentName": self._name,
@@ -210,6 +236,7 @@ class SegmentClientBase:
 
         post_data["key"] = permission["extra"]["objectPrefix"] + checksum
 
+        host = permission["extra"]["host"]
         backend_type = permission["extra"]["backendType"]
         if backend_type == "azure":
             url = (
@@ -218,9 +245,16 @@ class SegmentClientBase:
             )
 
             self._put_binary_file_to_azure(url, local_path, post_data)
+        elif backend_type == "fps":
+            self._post_multipart_formdata(
+                host,
+                local_path,
+                post_data,
+                checksum,
+            )
         else:
             self._post_multipart_formdata(
-                permission["extra"]["host"],
+                host,
                 local_path,
                 post_data,
             )
@@ -236,6 +270,7 @@ class SegmentClientBase:
         url: str,
         local_path: str,
         data: Dict[str, Any],
+        filename: str = "",
     ) -> None:
         with open(local_path, "rb") as fp:
             file_type = filetype.guess_mime(local_path)
@@ -243,7 +278,7 @@ class SegmentClientBase:
                 data["Content-Type"] = file_type
 
             try:
-                data["file"] = ("", fp, file_type)
+                data["file"] = (filename, fp, file_type)
                 self._post_formdata(url, data)
             except ResponseError as error:
                 if b"MalformedPOSTRequest" in error.response.content:
@@ -364,41 +399,34 @@ class SegmentClient(SegmentClientBase):
     def _generate_data(self, offset: int = 0, limit: int = 128) -> Generator[RemoteData, None, int]:
         response = self._list_data_details(offset, limit)
 
-        urls = _UrlGetters(
-            LazyPage.from_items(
-                offset,
-                limit,
-                self._generate_urls,
-                (item["url"] for item in response["dataDetails"]),
-            ),
+        urls = LazyPage.from_items(
+            offset,
+            limit,
+            self._generate_urls,
+            (item["url"] for item in response["dataDetails"]),
         )
 
         mask_urls = {}
         for key in _MASK_KEYS:
-            mask_urls[key] = _UrlGetters(
-                LazyPage(
-                    offset,
-                    limit,
-                    lambda offset, limit, k=key: self._generate_mask_urls(  # type: ignore[misc]
-                        k.upper(), offset, limit
-                    ),
+            mask_urls[key] = LazyPage(
+                offset,
+                limit,
+                lambda offset, limit, k=key: self._generate_mask_urls(  # type: ignore[misc]
+                    k.upper(), offset, limit
                 ),
             )
 
         for i, item in enumerate(response["dataDetails"]):
             data = RemoteData.from_response_body(
                 item,
-                _url_getter=urls[i],
-                _url_updater=urls.update,
+                url=URL.from_getter(urls.items[i].get, urls.pull),
                 cache_path=self._cache_path,
             )
             label = data.label
             for key in _MASK_KEYS:
                 mask = getattr(label, key, None)
                 if mask:
-                    # pylint: disable=protected-access
-                    mask._url_getter = mask_urls[key][i]
-                    mask._url_updater = mask_urls[key].update
+                    mask.url = URL.from_getter(mask_urls[key].items[i].get, mask_urls[key].pull)
                     mask.cache_path = os.path.join(self._cache_path, key, mask.path)
 
             yield data
@@ -672,6 +700,43 @@ class SegmentClient(SegmentClientBase):
         """
         return PagingList(self._generate_data_paths, 128)
 
+    def get_data(self, remote_path: str) -> RemoteData:
+        """Get required Data object from a dataset segment.
+
+        Arguments:
+            remote_path: The remote paths of the required data.
+
+        Returns:
+            :class:`~tensorbay.dataset.data.RemoteData`.
+
+        Raises:
+            ResourceNotExistError: When the required data does not exist.
+
+        """
+        if not remote_path:
+            raise ResourceNotExistError(resource="data", identification=remote_path)
+
+        data_details = self._get_data_details(remote_path)
+        data = RemoteData.from_response_body(
+            data_details,
+            url=URL(data_details["url"], lambda: self._get_url(remote_path)),
+            cache_path=self._cache_path,
+        )
+        label = data.label
+
+        for key in _MASK_KEYS:
+            mask = getattr(label, key, None)
+            if mask:
+                mask.url = URL.from_getter(
+                    lambda k=key.upper(), r=remote_path: self._get_mask_url(k, r),
+                    lambda k=key.upper(), r=remote_path: (  # type: ignore[misc, arg-type]
+                        self._get_mask_url(k, r)
+                    ),
+                )
+                mask.cache_path = os.path.join(self._cache_path, key, mask.path)
+
+        return data
+
     def list_data(self) -> PagingList[RemoteData]:
         """List required Data object in a dataset segment.
 
