@@ -15,9 +15,9 @@ such as the coordinates and visible status(optional).
 
 from typing import Dict, Iterable, List, Optional, Type, TypeVar
 
-from ..utility import common_loads
-from .polygon import PointList2D
-from .vector import Vector2D
+from tensorbay.geometry.point_list import PointList2D
+from tensorbay.geometry.vector import Vector2D
+from tensorbay.utility import common_loads
 
 _T = TypeVar("_T", bound=Vector2D)
 
@@ -35,13 +35,13 @@ class Keypoint2D(Vector2D):
 
             Visible status can be "BINARY" or "TERNARY":
 
-            +---------------+---------+-----------+-----------+
-            | Visual Status | v = 0   | v = 1     | v = 2     |
-            +===============+=========+===========+===========+
-            | BINARY        | visible | invisible |           |
-            +---------------+---------+-----------+-----------+
-            | TERNARY       | visible | occluded  | invisible |
-            +---------------+---------+-----------+-----------+
+            +---------------+-----------+-----------+---------+
+            | Visual Status | v = 0     | v = 1     | v = 2   |
+            +===============+===========+===========+=========+
+            | BINARY        | invisible | visible   |         |
+            +---------------+-----------+-----------+---------+
+            | TERNARY       | invisible | occluded  | visible |
+            +---------------+-----------+-----------+---------+
 
     Examples:
         *Initialization Method 1:* Init from coordinates of x, y.
