@@ -12,12 +12,12 @@ and provides :meth:`Polygon.area` to calculate the area of the polygon.
 
 from typing import Dict, Iterable, List, Optional, Type, TypeVar
 
-from ..utility import UserMutableSequence, common_loads
-from .point_list import MultiPointList2D, PointList2D
-from .vector import Vector2D
+from tensorbay.geometry.point_list import MultiPointList2D, PointList2D
+from tensorbay.geometry.vector import Vector2D
+from tensorbay.utility import UserMutableSequence, common_loads
 
 
-class Polygon(PointList2D[Vector2D]):  # pylint: disable=too-many-ancestors
+class Polygon(PointList2D[Vector2D]):
     """This class defines the concept of Polygon.
 
     :class:`Polygon` contains the coordinates of the vertexes of the polygon and provides
@@ -76,7 +76,7 @@ class Polygon(PointList2D[Vector2D]):  # pylint: disable=too-many-ancestors
 
         """
         area = 0.0
-        for i in range(len(self._data)):
+        for i in range(len(self._data)):  # pylint: disable=consider-using-enumerate
             # pylint: disable=invalid-name
             x1, y1 = self._data[i - 1]
             x2, y2 = self._data[i]
@@ -84,7 +84,7 @@ class Polygon(PointList2D[Vector2D]):  # pylint: disable=too-many-ancestors
         return area / 2
 
 
-class MultiPolygon(MultiPointList2D[Polygon]):  # pylint: disable=too-many-ancestors
+class MultiPolygon(MultiPointList2D[Polygon]):
     """This class defines the concept of MultiPolygon.
 
     :class:`MultiPolygon` contains a list of polygons.
