@@ -15,9 +15,21 @@ coordinates of a 2D vector or a 3D vector.
 """
 
 from itertools import zip_longest
+from math import hypot, sqrt
+from sys import version_info
 from typing import Dict, Iterable, Optional, Sequence, Tuple, Type, TypeVar, Union
 
-from ..utility import ReprType, UserSequence
+from tensorbay.utility import ReprType, UserSequence
+
+if version_info >= (3, 8):
+    # math.hypot method supports n-dimensional points in Python3.8
+    # only the two dimensional case was supported before Python3.8
+    _hypot_for_n_dimension = hypot
+else:
+
+    def _hypot_for_n_dimension(*coordinates: float) -> float:  # type: ignore[misc]
+        return sqrt(sum(x * x for x in coordinates))
+
 
 _V = TypeVar("_V", bound="Vector")
 _V2 = TypeVar("_V2", bound="Vector2D")
@@ -36,10 +48,12 @@ class Vector(UserSequence[float]):
         y: The y coordinate of the vector.
         z: The z coordinate of the vector.
 
-            .. code:: python
+    Examples:
+        >>> Vector(1, 2)
+        Vector2D(1, 2)
 
-                vector2d = Vector(x=1, y=2)
-                vector3d = Vector(x=1, y=2, z=3)
+        >>> Vector(1, 2, 3)
+        Vector3D(1, 2, 3)
 
     """
 
@@ -62,11 +76,6 @@ class Vector(UserSequence[float]):
             y: The y coordinate of the vector.
             z: The z coordinate of the vector.
 
-                .. code:: python
-
-                    vector2d = Vector(x=1, y=2)
-                    vector3d = Vector(x=1, y=2, z=3)
-
         Returns:
             The created :class:`Vector2D` or :class:`Vector3D` object.
 
@@ -84,12 +93,6 @@ class Vector(UserSequence[float]):
         result._data = tuple(-coordinate for coordinate in self._data)
         return result
 
-    def __eq__(self, other: object) -> bool:
-        if not isinstance(other, self.__class__):
-            return False
-
-        return self._data.__eq__(other._data)
-
     def __add__(self: _V, other: Iterable[float]) -> _V:
         """Calculate the sum of the vector and other vector.
 
@@ -119,6 +122,61 @@ class Vector(UserSequence[float]):
         """
         return self.__add__(other)
 
+    def __sub__(self: _V, other: Iterable[float]) -> _V:
+        try:
+            result: _V = object.__new__(self.__class__)
+            result._data = tuple(i - j for i, j in zip_longest(self._data, other))
+            return result
+        except TypeError:
+            return NotImplemented
+
+    def __rsub__(self: _V, other: Iterable[float]) -> _V:
+        try:
+            result: _V = object.__new__(self.__class__)
+            result._data = tuple(i - j for i, j in zip_longest(other, self._data))
+            return result
+        except TypeError:
+            return NotImplemented
+
+    def __mul__(self: _V, other: float) -> _V:
+        try:
+            if isinstance(other, (int, float)):
+                result: _V = object.__new__(self.__class__)
+                result._data = tuple(i * other for i in self._data)
+                return result
+        except TypeError:
+            pass
+
+        return NotImplemented
+
+    def __rmul__(self: _V, other: float) -> _V:
+        return self.__mul__(other)
+
+    def __truediv__(self: _V, other: float) -> _V:
+        try:
+            if isinstance(other, (int, float)):
+                result: _V = object.__new__(self.__class__)
+                result._data = tuple(i / other for i in self._data)
+                return result
+        except TypeError:
+            pass
+
+        return NotImplemented
+
+    def __floordiv__(self: _V, other: float) -> _V:
+        try:
+            if isinstance(other, (int, float)):
+                result: _V = object.__new__(self.__class__)
+                result._data = tuple(i // other for i in self._data)
+                return result
+        except TypeError:
+            pass
+
+        return NotImplemented
+
+    def __abs__(self) -> float:
+        return _hypot_for_n_dimension(*self._data)
+
     def _repr_head(self) -> str:
         return f"{self.__class__.__name__}{self._data}"
 
@@ -127,22 +185,20 @@ class Vector(UserSequence[float]):
         """Loads a :class:`Vector` from a dict containing coordinates of the vector.
 
         Arguments:
-            contents: A dict containing coordinates of the vector::
-
-                {
-                    "x": ...
-                    "y": ...
-                }
-                or
-                {
-                    "x": ...
-                    "y": ...
-                    "z": ...
-                }
+            contents: A dict containing coordinates of the vector.
 
         Returns:
             The loaded :class:`Vector2D` or :class:`Vector3D` object.
 
+        Examples:
+            >>> contents = {"x": 1.0, "y": 2.0}
+            >>> Vector.loads(contents)
+            Vector2D(1.0, 2.0)
+
+            >>> contents = {"x": 1.0, "y": 2.0, "z": 3.0}
+            >>> Vector.loads(contents)
+            Vector3D(1.0, 2.0, 3.0)
+
         """
         if "z" in contents:
             return Vector3D.loads(contents)
@@ -158,6 +214,10 @@ class Vector2D(Vector):
         x: The x coordinate of the 2D vector.
         y: The y coordinate of the 2D vector.
 
+    Examples:
+        >>> Vector2D(1, 2)
+        Vector2D(1, 2)
+
     """
 
     _DIMENSION = 2
@@ -181,21 +241,24 @@ class Vector2D(Vector):
     def __init__(self, x: float, y: float) -> None:
         self._data = (x, y)
 
+    def __abs__(self) -> float:
+        return hypot(*self._data)
+
     @classmethod
     def loads(cls: Type[_V2], contents: Dict[str, float]) -> _V2:
         """Load a :class:`Vector2D` object from a dict containing coordinates of a 2D vector.
 
         Arguments:
-            contents: A dict containing coordinates of a 2D vector::
-
-                {
-                    "x": ...
-                    "y": ...
-                }
+            contents: A dict containing coordinates of a 2D vector.
 
         Returns:
             The loaded :class:`Vector2D` object.
 
+        Examples:
+            >>> contents = {"x": 1.0, "y": 2.0}
+            >>> Vector2D.loads(contents)
+            Vector2D(1.0, 2.0)
+
         """
         return cls(**contents)
 
@@ -206,6 +269,11 @@ class Vector2D(Vector):
         Returns:
             X coordinate in float type.
 
+        Examples:
+            >>> vector_2d = Vector2D(1, 2)
+            >>> vector_2d.x
+            1
+
         """
         return self._data[0]
 
@@ -216,6 +284,11 @@ class Vector2D(Vector):
         Returns:
             Y coordinate in float type.
 
+        Examples:
+            >>> vector_2d = Vector2D(1, 2)
+            >>> vector_2d.y
+            2
+
         """
         return self._data[1]
 
@@ -225,6 +298,11 @@ class Vector2D(Vector):
         Returns:
             A dict containing the vector coordinate.
 
+        Examples:
+                >>> vector_2d = Vector2D(1, 2)
+                >>> vector_2d.dumps()
+                {'x': 1, 'y': 2}
+
         """
         return {"x": self._data[0], "y": self._data[1]}
 
@@ -239,6 +317,10 @@ class Vector3D(Vector):
         y: The y coordinate of the 3D vector.
         z: The z coordinate of the 3D vector.
 
+    Examples:
+        >>> Vector3D(1, 2, 3)
+        Vector3D(1, 2, 3)
+
     """
 
     _DIMENSION = 3
@@ -267,17 +349,16 @@ class Vector3D(Vector):
         """Load a :class:`Vector3D` object from a dict containing coordinates of a 3D vector.
 
         Arguments:
-            contents: A dict contains coordinates of a 3D vector::
-
-                {
-                    "x": ...
-                    "y": ...
-                    "z": ...
-                }
+            contents: A dict contains coordinates of a 3D vector.
 
         Returns:
             The loaded :class:`Vector3D` object.
 
+        Examples:
+            >>> contents = {"x": 1.0, "y": 2.0, "z": 3.0}
+            >>> Vector3D.loads(contents)
+            Vector3D(1.0, 2.0, 3.0)
+
         """
         return cls(**contents)
 
@@ -288,6 +369,11 @@ class Vector3D(Vector):
         Returns:
              X coordinate in float type.
 
+        Examples:
+            >>> vector_3d = Vector3D(1, 2, 3)
+            >>> vector_3d.x
+            1
+
         """
         return self._data[0]
 
@@ -298,6 +384,11 @@ class Vector3D(Vector):
         Returns:
             Y coordinate in float type.
 
+        Examples:
+            >>> vector_3d = Vector3D(1, 2, 3)
+            >>> vector_3d.y
+            2
+
         """
         return self._data[1]
 
@@ -308,6 +399,11 @@ class Vector3D(Vector):
         Returns:
             Z coordinate in float type.
 
+        Examples:
+            >>> vector_3d = Vector3D(1, 2, 3)
+            >>> vector_3d.z
+            3
+
         """
         return self._data[2]
 
@@ -317,5 +413,10 @@ class Vector3D(Vector):
         Returns:
             A dict containing the vector coordinates.
 
+        Examples:
+            >>> vector_3d = Vector3D(1, 2, 3)
+            >>> vector_3d.dumps()
+            {'x': 1, 'y': 2, 'z': 3}
+
         """
         return {"x": self._data[0], "y": self._data[1], "z": self._data[2]}
