@@ -35,14 +35,18 @@ corresponding to different types of labels.
 from functools import partial
 from typing import Any, Dict, Iterator, Type, TypeVar
 
-from ..utility import AttrsMixin, ReprMixin, ReprType, attr, common_loads, upper
-from .label_box import Box2DSubcatalog, Box3DSubcatalog
-from .label_classification import ClassificationSubcatalog
-from .label_keypoints import Keypoints2DSubcatalog
-from .label_mask import InstanceMaskSubcatalog, PanopticMaskSubcatalog, SemanticMaskSubcatalog
-from .label_polygon import MultiPolygonSubcatalog, PolygonSubcatalog, RLESubcatalog
-from .label_polyline import MultiPolyline2DSubcatalog, Polyline2DSubcatalog
-from .label_sentence import SentenceSubcatalog
+from tensorbay.label.label_box import Box2DSubcatalog, Box3DSubcatalog
+from tensorbay.label.label_classification import ClassificationSubcatalog
+from tensorbay.label.label_keypoints import Keypoints2DSubcatalog
+from tensorbay.label.label_mask import (
+    InstanceMaskSubcatalog,
+    PanopticMaskSubcatalog,
+    SemanticMaskSubcatalog,
+)
+from tensorbay.label.label_polygon import MultiPolygonSubcatalog, PolygonSubcatalog, RLESubcatalog
+from tensorbay.label.label_polyline import MultiPolyline2DSubcatalog, Polyline2DSubcatalog
+from tensorbay.label.label_sentence import SentenceSubcatalog
+from tensorbay.utility import AttrsMixin, ReprMixin, ReprType, attr, common_loads, upper
 
 _ERROR_MESSAGE = "The '{attr_name}' subcatalog is not provided in this dataset"
 _attr = partial(attr, is_dynamic=True, key=upper, error_message=_ERROR_MESSAGE)
