@@ -26,8 +26,8 @@ from typing import Dict, Iterator, Optional, Sequence, Tuple, Type, TypeVar
 
 import numpy as np
 
-from ..geometry import Vector2D
-from ..utility import AttrsMixin, MatrixType, ReprMixin, ReprType, attr, camel, common_loads
+from tensorbay.geometry import Vector2D
+from tensorbay.utility import AttrsMixin, MatrixType, ReprMixin, ReprType, attr, camel, common_loads
 
 
 class CameraMatrix(ReprMixin, AttrsMixin):
@@ -320,8 +320,8 @@ class DistortionCoefficients(ReprMixin, AttrsMixin):
         if is_fisheye:
             return (0, 0)
 
-        p1 = self.p1  # type: ignore[attr-defined]  # pylint: disable=no-member
-        p2 = self.p2  # type: ignore[attr-defined]  # pylint: disable=no-member
+        p1: float = self.p1  # type: ignore[attr-defined]
+        p2: float = self.p2  # type: ignore[attr-defined]
         return (p1 * xy2 + p2 * (r2 + 2 * x2), p1 * (r2 + 2 * y2) + p2 * xy2)
 
     def _loads(self, contents: Dict[str, float]) -> None:
