@@ -13,10 +13,11 @@ from tensorbay.utility.deprecated import (
     Disable,
     KwargsDeprecated,
 )
-from tensorbay.utility.file import FileMixin, RemoteFileMixin
+from tensorbay.utility.file import URL, FileMixin, RemoteFileMixin
 from tensorbay.utility.itertools import chunked
 from tensorbay.utility.name import NameList, NameMixin, SortedNameList
 from tensorbay.utility.repr import ReprMixin, ReprType, repr_config
+from tensorbay.utility.request_config import config
 from tensorbay.utility.type import TypeEnum, TypeMixin, TypeRegister
 from tensorbay.utility.user import (
     UserMapping,
@@ -43,6 +44,7 @@ __all__ = [
     "TypeEnum",
     "TypeMixin",
     "TypeRegister",
+    "URL",
     "UserMapping",
     "UserMutableMapping",
     "UserMutableSequence",
@@ -52,6 +54,7 @@ __all__ = [
     "camel",
     "chunked",
     "common_loads",
+    "config",
     "locked",
     "repr_config",
     "upper",
